<?php

/**
 * @file
 * Contains \Drupal\yamlform\Plugin\YamlFormElement\TextField.
 */

namespace Drupal\yamlform\Plugin\YamlFormElement;

use Drupal\Core\Form\FormStateInterface;
use Drupal\yamlform\YamlFormElementBase;
use Drupal\yamlform\YamlFormSubmissionInterface;

/**
 * Provides a base 'textfield' class.
 */
abstract class TextFieldBase extends YamlFormElementBase {

  /**
   * {@inheritdoc}
   */
  public function getDefaultProperties() {
    return parent::getDefaultProperties() + [
      'size' => '',
      'maxlength' => '',
      'placeholder' => '',
      'input_mask' => '',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function prepare(array &$element, YamlFormSubmissionInterface $yamlform_submission) {
    parent::prepare($element, $yamlform_submission);

    // Convert custom #autocomplete property to a FAPI autocomplete route
    // that return YAML form options.
    if (isset($element['#autocomplete'])) {
      $element['#autocomplete_route_name'] = 'yamlform.options_autocomplete';
      $element['#autocomplete_route_parameters'] = [
        'yamlform' => $yamlform_submission->getYamlForm()->id(),
        'key' => $element['#yamlform_key'],
      ];
    }

    // Input mask support.
    if (isset($element['#input_mask'])) {
      // See if the element mask is JSON by looking for 'name':, else assume it
      // is a mask pattern.
      $input_mask = $element['#input_mask'];
      if (preg_match("/^'[^']+'\s*:/", $input_mask)) {
        $element['#attributes']['data-inputmask'] = $input_mask;
      }
      else {
        $element['#attributes']['data-inputmask-mask'] = $input_mask;
      }

      $element['#attributes']['class'][] = 'js-yamlform-element-mask';
      $element['#attached']['library'][] = 'yamlform/jquery.inputmask';
    }
  }

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);
    $form['form']['input_mask'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Inputs masks'),
      '#description' => $this->t('An <a href=":href">inputmask</a> helps the user with the element by ensuring a predefined format. (9 = numeric; a = alphabetical; * = alphanumeric)', [':href' => 'https://github.com/RobinHerbots/jquery.inputmask']),
    ];
    return $form;
  }

}
